;; Generated package description from ediprolog.el  -*- no-byte-compile: t -*-
(define-package "ediprolog" "2.1.0.20201129.215717" "Emacs Does Interactive Prolog" 'nil :keywords '("languages" "processes") :authors '(("Markus Triska" . "triska@metalevel.at")) :maintainer '("Markus Triska" . "triska@metalevel.at") :url "https://www.metalevel.at/ediprolog/")
